@@ -1,5 +1,11 @@
 // acconfig.h symbols and macros for libstdc++ v3 -*- C++ -*-
 
+// Define if GCC support for __complex__ float is buggy.
+#undef _GLIBCPP_BUGGY_FLOAT_COMPLEX
+
+// Define if GCC support for __complex__ is buggy.
+#undef _GLIBCPP_BUGGY_COMPLEX
+
 // Include support for multiple threads, e.g., in the I/O package.
 #undef _GLIBCPP_USE_THREADS
 
@@ -12,15 +18,30 @@
 // Include support for shadow headers, ie --enable-cshadow-headers.
 #undef _GLIBCPP_USE_SHADOW_HEADERS
 
-// Define if the host has a type mbstate_t defined in
-// wchar.h, as required by 21.1.3.1. Some systems, namely
-// hppa-hp-hpux10.20 do not meet this requirement, and must be worked
-// around.
-#undef _GLIBCPP_NEED_MBSTATE_T
-
 // Define if code specialized for wchar_t should be used.
 #undef _GLIBCPP_USE_WCHAR_T
 
+// Define if you have the atan2f function.
+#undef _GLIBCPP_HAVE_ATAN2F 
+
+// Define if you have the atan2l function.
+#undef _GLIBCPP_HAVE_ATAN2L
+
+// Define if you have the copysignf function.
+#undef _GLIBCPP_HAVE_COPYSIGNF
+
+// Define if lldiv_t exists in stdlib.h.
+#undef HAVE_LLDIV_T
+
+// Define if mbstate_t exists in wchar.h.  */
+#undef HAVE_MBSTATE_T
+
+// Define if you have the modff function.  */
+#undef HAVE_MODFF
+
+// Define if you have the modfl function.  */
+#undef HAVE_MODFL
+
 // Define if the compiler/host combination has __builtin_abs
 #undef HAVE___BUILTIN_ABS
 
@@ -63,12 +84,6 @@
 // Define if the compiler/host combination has __builtin_sqrtl
 #undef HAVE___BUILTIN_SQRTL
 
-// Define if GCC support for __complex__ float is buggy.
-#undef _GLIBCPP_BUGGY_FLOAT_COMPLEX
-
-// Define if GCC support for __complex__ is buggy.
-#undef _GLIBCPP_BUGGY_COMPLEX
-
 // Define if LC_MESSAGES is available in <locale.h>.
 #undef HAVE_LC_MESSAGES
 
