@@ -1,7 +1,7 @@
 // 1999-06-29
 // bkoz 
 
-// Copyright (C) 1999 Free Software Foundation, Inc.
+// Copyright (C) 1999, 2000 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -22,16 +22,14 @@
 // 23.2.4.1 vector constructors, copy, and assignment
 
 #include <vector>
-#ifdef DEBUG_ASSERT
-#include <assert.h>
-#endif
+#include <debug_assert.h>
 
 template<typename T>
   struct A { };
 
 struct B { };
 
-bool test01()
+void test01()
 {
 
   // 1
@@ -45,18 +43,25 @@ bool test01()
 #ifdef DEBUG_ASSERT
   assert(test);
 #endif
-  
-  return test;
 }
 
 // 2
-template class vector<double>;
-template class vector< A<B> >;
+template class std::vector<double>;
+template class std::vector< A<B> >;
+
+
+// libstdc++/102
+void test02()
+{
+  std::vector<int> v1;
+  std::vector<int> v2 (v1);
+}
+
 
 int main()
 {
   test01();
-
+  test02(); 
   return 0;
 }
 
