@@ -1,6 +1,6 @@
 // 1999-10-11 bkoz
 
-// Copyright (C) 1999 Free Software Foundation, Inc.
+// Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -29,32 +29,34 @@
 
 // 27.5.2 template class basic_streambuf
 
+#include <cstring> // for memset, memcmp
 #include <streambuf>
+#include <string>
 #include <ostream>
-#ifdef DEBUG_ASSERT
-#include <assert.h>
-#endif
+#include <debug_assert.h>
 
-class testbuf : public streambuf
+class testbuf : public std::streambuf
 {
 public:
 
-  // Typdefs:
-  typedef streambuf::traits_type traits_type;
+  // Typedefs:
+  typedef std::streambuf::traits_type traits_type;
+  typedef std::streambuf::char_type char_type;
 
-  testbuf(): streambuf() 
-  { _M_mode = (ios_base::in | ios_base::out); }
+  testbuf(): std::streambuf() 
+  { _M_mode = (std::ios_base::in | std::ios_base::out); }
 
-  int_type
+  bool
   check_pointers()
   { 
-    int_type g1 = reinterpret_cast<int_type>(this->eback());
-    int_type g2 = reinterpret_cast<int_type>(this->gptr());
-    int_type g3 = reinterpret_cast<int_type>(this->egptr());
-    int_type p1 = reinterpret_cast<int_type>(this->pbase());
-    int_type p2 = reinterpret_cast<int_type>(this->pptr());
-    int_type p3 = reinterpret_cast<int_type>(this->epptr());
-    return g1 + g2 + g3 + p1 + p2 + p3;
+    bool test = true;
+    VERIFY( this->eback() == NULL );
+    VERIFY( this->gptr() == NULL );
+    VERIFY( this->egptr() == NULL );
+    VERIFY( this->pbase() == NULL );
+    VERIFY( this->pptr() == NULL );
+    VERIFY( this->epptr() == NULL );
+    return test;
   }
 
   int_type 
@@ -101,52 +103,52 @@ void test01()
   // default ctor initializes 
   // - all pointer members to null pointers
   // - locale to current global locale
-  test &= buf01.check_pointers() == 0;
-  test &= buf01.getloc() == std::locale();
+  VERIFY( buf01.check_pointers() );
+  VERIFY( buf01.getloc() == std::locale() );
 
   // 27.5.2.3.1 get area
   // 27.5.2.2.3 get area
   // 27.5.2.4.3 get area
   int i01 = 3;
   buf01.pub_setg(lit01, lit01, (lit01 + i01));
-  test &= i01 == buf01.in_avail();
+  VERIFY( i01 == buf01.in_avail() );
 
-  test &= buf01.pub_uflow() == lit01[0];
-  test &= buf01.sgetc() == traits_type::to_int_type(lit01[1]);
-  test &= buf01.pub_uflow() == lit01[1];
-  test &= buf01.sgetc() == traits_type::to_int_type(lit01[2]);
-  test &= buf01.pub_uflow() == lit01[2];
-  test &= buf01.sgetc() == traits_type::eof();
+  VERIFY( buf01.pub_uflow() == lit01[0] );
+  VERIFY( buf01.sgetc() == traits_type::to_int_type(lit01[1]) );
+  VERIFY( buf01.pub_uflow() == lit01[1] );
+  VERIFY( buf01.sgetc() == traits_type::to_int_type(lit01[2]) );
+  VERIFY( buf01.pub_uflow() == lit01[2] );
+  VERIFY( buf01.sgetc() == traits_type::eof() );
 
   // pbackfail
   buf01.pub_setg(lit01, lit01, (lit01 + i01));
-  test &= i01 == buf01.in_avail();
+  VERIFY( i01 == buf01.in_avail() );
   int_type intt01 = traits_type::to_int_type('b');
-  test &= traits_type::eof() == buf01.pub_pbackfail(intt01);
+  VERIFY( traits_type::eof() == buf01.pub_pbackfail(intt01) );
 
   // overflow
-  test &= traits_type::eof() == buf01.pub_overflow(intt01);
-  test &= traits_type::eof() == buf01.pub_overflow();
-  test &= buf01.sgetc() == traits_type::to_int_type(lit01[0]);
+  VERIFY( traits_type::eof() == buf01.pub_overflow(intt01) );
+  VERIFY( traits_type::eof() == buf01.pub_overflow() );
+  VERIFY( buf01.sgetc() == traits_type::to_int_type(lit01[0]) );
 
   // sputn/xsputn
   char* lit02 = "isotope 217: the unstable molecule on thrill jockey";
-  int i02 = strlen(lit02);
+  int i02 = std::strlen(lit02);
   char carray[i02 + 1];
-  memset(carray, 0, i02 + 1);
+  std::memset(carray, 0, i02 + 1);
 
   buf01.pub_setp(carray, (carray + i02));
   buf01.sputn(lit02, 0);
-  test &= carray[0] == 0;
-  test &= lit02[0] == 'i';
+  VERIFY( carray[0] == 0 );
+  VERIFY( lit02[0] == 'i' );
   buf01.sputn(lit02, 1);
-  test &= lit02[0] == carray[0];
-  test &= lit02[1] == 's';
-  test &= carray[1] == 0;
+  VERIFY( lit02[0] == carray[0] );
+  VERIFY( lit02[1] == 's' );
+  VERIFY( carray[1] == 0 );
   buf01.sputn(lit02 + 1, 10);
-  test &= memcmp(lit02, carray, 10) == 0;
+  VERIFY( std::memcmp(lit02, carray, 10) == 0 );
   buf01.sputn(lit02 + 11, 20);
-  test &= memcmp(lit02, carray, 30) == 0;
+  VERIFY( std::memcmp(lit02, carray, 30) == 0 );
 
 #ifdef DEBUG_ASSERT
   assert(test);
@@ -166,23 +168,23 @@ void test02()
   // default ctor initializes 
   // - all pointer members to null pointers
   // - locale to current global locale
-  test &= buf01.check_pointers() == 0;
-  test &= buf01.getloc() == std::locale();
+  VERIFY( buf01.check_pointers() );
+  VERIFY( buf01.getloc() == std::locale() );
 
   // 27.5.2.2.5 Put area
   size_t i01 = traits_type::length(lit01);
   char carray01[i01];
-  memset(carray01, 0, i01);
+  std::memset(carray01, 0, i01);
   
   buf01.pub_setg(lit01, lit01, lit01 + i01);
   buf01.sgetn(carray01, 0);
-  test &= carray01[0] == 0;
+  VERIFY( carray01[0] == 0 );
   buf01.sgetn(carray01, 1);
-  test &= carray01[0] == 'c';
+  VERIFY( carray01[0] == 'c' );
   buf01.sgetn(carray01 + 1, i01 - 1);
-  test &= carray01[0] == 'c';
-  test &= carray01[1] == 'h';
-  test &= carray01[i01 - 1] == 'k';
+  VERIFY( carray01[0] == 'c' );
+  VERIFY( carray01[1] == 'h' );
+  VERIFY( carray01[i01 - 1] == 'k' );
 
 #ifdef DEBUG_ASSERT
   assert(test);
@@ -190,7 +192,7 @@ void test02()
 }
  
 // test03
-// http://sourceware.cygnus.com/ml/libstdc++/2000-q1/msg00151.html
+// http://gcc.gnu.org/ml/libstdc++/2000-q1/msg00151.html
 template<typename charT, typename traits = std::char_traits<charT> >
   class basic_nullbuf : public std::basic_streambuf<charT, traits>
   {
@@ -216,8 +218,8 @@ template<typename T>
 void test03() 
 {
   bool test = true;
-  const string control01("11111");
-  string test01;
+  const std::string control01("11111");
+  std::string test01;
 
   test01 += print(true);
   test01 += print(3.14159);
@@ -225,12 +227,115 @@ void test03()
   test01 += print('x');
   test01 += print("pipo");
 
-  test &= test01 == control01;
+  VERIFY( test01 == control01 );
 #ifdef DEBUG_ASSERT
   assert(test);
 #endif
 }
 
+class setpbuf : public std::streambuf
+{
+  char 		buffer[4];
+  std::string 	result;
+
+public:
+
+  std::string&
+  get_result()
+  { return result; }
+
+  setpbuf()
+  {
+    char foo [32];
+    setp(foo, foo + 32);
+    setp(buffer, buffer + 4);
+  }
+
+  ~setpbuf()
+  { sync(); }
+
+  virtual int_type 
+  overflow(int_type n)
+  {
+    if (sync() != 0)
+      return traits_type::eof();
+    
+    result += traits_type::to_char_type(n);
+    
+    return n;
+  }
+  
+  virtual int 
+  sync()
+  {
+    result.append(pbase(), pptr());
+    setp(buffer, buffer + 4);
+    return 0;
+  }
+};
+
+// libstdc++/1057
+void test04()
+{
+  bool test = true;
+  std::string text = "abcdefghijklmn";
+  
+  // 01
+  setpbuf sp1;
+  // Here xsputn writes over sp1.result
+  sp1.sputn(text.c_str(), text.length());
+
+  // This crashes when result is accessed
+  sp1.pubsync();
+  VERIFY( sp1.get_result() == text );
+  
+
+  // 02
+  setpbuf sp2;
+  for (std::string::size_type i = 0; i < text.length(); ++i)
+    {
+      // sputc also writes over result
+      sp2.sputc(text[i]);
+    }
+  
+  // Crash here
+  sp2.pubsync();
+  VERIFY( sp2.get_result() == text );
+}
+
+class nullsetpbuf : public std::streambuf
+{
+  char foo[64];
+public:
+  nullsetpbuf()
+  {
+    setp(foo, foo + 64);
+    setp(NULL, NULL);
+  }
+};
+
+// libstdc++/1057
+void test05()
+{
+    std::string text1 = "abcdefghijklmn";
+
+    nullsetpbuf nsp;
+    // Immediate crash as xsputn writes to null pointer
+    nsp.sputn(text1.c_str(), text1.length());
+    // ditto
+    nsp.sputc('a');
+}
+
+// test06
+// XXX this should work, doesn't due to compiler limitations.
+#if 0
+namespace gnu 
+{
+  class something_derived;
+}
+
+class gnu::something_derived : std::streambuf { };
+#endif
 
 int main() 
 {
@@ -238,6 +343,8 @@ int main()
   test02();
   test03();
 
+  test04();
+  test05();
   return 0;
 }
 
